anesthetic.read package
=======================

Submodules
----------

anesthetic.read.base module
---------------------------

.. automodule:: anesthetic.read.base
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.read.getdist module
------------------------------

.. automodule:: anesthetic.read.getdist
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.read.multinest module
--------------------------------

.. automodule:: anesthetic.read.multinest
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.read.nested module
-----------------------------

.. automodule:: anesthetic.read.nested
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.read.polychord module
--------------------------------

.. automodule:: anesthetic.read.polychord
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: anesthetic.read
    :members:
    :undoc-members:
    :show-inheritance:
